====================================
KLOUDBUSTER IMAGE BUILD INSTRUCTIONS
====================================

Refer to `here <http://kloudbuster.readthedocs.org/en/latest/installation.html#build-vm-image>`_ for the instructions of building KloudBuster image.
